<%inherit file="public_basewithmenu.html" /> <%block name="head"> ${parent.head()}

#### Type & code:

Classifiers to use:

Text to code:
Agreement on last assigned labels: n/a
Agreement history:
Service access info:

IP-based access is the default access method when accessing the service without login or a key.

A Key-based access requires inserting an identification key (a long alfa-numeric string) in the text box below.

An empty or wrong key will back up to IP-based access.

All access methods may set a limit to the number of requests per hour and their total number.

A value for the request limit equal to "n/a" means no access.

A value equal to "-1" means unlimited requests.

IP-based access
IP: ${ip}
IP requests this hour: 0 - limit: 0
Total IP requests: 0 - limit: 0
Key-based access.
Key requests this hour: 0 - limit: 0
Total key requests: 0 - limit: 0